gpa

# XMLRésuméLibrary: User Guide

from | Element Reference | head

## Name

gpa — Information about a grade point average

## Synopsis

### Content Model

    (score,possible?,note?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None
type | Enumeration:
`overall`
`major`
| `overall`

## Description

The `gpa` element contains a information about a grade point average, or GPA. A GPA is a number that averages the scores of different subjects (such as mathematics, English, history, etc.).

### Parents

`gpa` may be contained in these elements: `degree`

### Attributes

`type`

  Indicates whether the GPA refers to all courses taken toward a degree, or just those in the major field of study. Possible values: `overall` and `major`. Default is `overall`.

## Examples

    <gpa type="major">
      <score>3.78</score>
      <possible>4.00</possible>
      <note>This is on a weighted scale.</note>
    </gpa>

    <gpa>
      <score>3</score>
    </gpa>

from | Element Reference | head